#!/usr/bin/python3
#
# Script to control presets for radio cards.
# Requires fmtools.
#
# Author: Paulo Roma on 27/12/2009
# Usage: fmcontrol [station] [volume]
#
# You might want to edit the next few lines.
#
# This sets the path to the station config file FROM INSIDE your home directory.
# Obviously if multiple users are using this script this must be the same for each.
# The STATIONFILE contains triples of the form (one per line): 
#         station name, frequency, volume
STATIONFILE = "/.radiostations"

# This is the default volume:
DEFAULTVOLUME = "50"

# This is the path to the fm binary:
FMPATH = "/usr/bin/fm"

# Unless you want to fiddle with the script you shouldn't need to change
# anything under here.

#*********************************************************************

import os, sys

def getFreq ( fname, station ):
    """ Return the frequency of the given station."""

    while ( True ):
      if ( station ):
         line = os.popen ( "grep -e ^" + station + " " + fname ).readline()
         if line:
            frequency = line.split (None)[1]
            volchange = line.split (None)[2]
            break
         else:
            print("Invalid station or error in config file.")
      else:
         print("No station specified.")

      print("Available Stations are: ")
      os.system ("more " + fname)
      if (sys.hexversion > 0x03000000):
         station = input ( "Please enter a station name: " )
      else:
         station = raw_input ( "Please enter a station name: " )

    return (frequency, volchange)

def main (argv = None):
    if argv is None:
       argv = sys.argv

    if len(argv) < 2:
       if (sys.hexversion > 0x03000000):
          n = input ( "An station name is needed: " )
       else:
          n = raw_input ( "An station name is needed: " )
       argv.append ( n )

    path = os.environ.get("HOME")
    fname = path + STATIONFILE

    if ( not os.path.exists (fname) ):
         exit ( "No " + fname + " found" )

    vol = os.popen ( "grep -e ^VOL " + fname ).readline()
    if ( vol ):
         VOLUME = vol.split (None)[1] 
    else:
         VOLUME = DEFAULTVOLUME

    (FREQUENCY, VOLCHANGE) = getFreq ( fname, argv[1] )

    if len ( argv ) > 2:
        VOLUME = argv[2]
    else:
        VOLUME += VOLCHANGE

    os.system ( FMPATH + " " + FREQUENCY + " " + VOLUME )
    os.system ( FMPATH + " on" )

try:
  if __name__=="__main__":
     sys.exit(main())
except (KeyboardInterrupt,SystemExit) as msg:
     sys.exit(msg)
